imply-package: imply: Efficiently Apply Functions to Images

imply-packageR Documentation

imply: Efficiently Apply Functions to Images

Description

Infrastructure for handling generalised two and three dimensional images, which may hold multiple values at each spatial location, and efficiently applying functions to them. Dense, compacted and sparse pixel/voxel representations are supported, with one core engine for processing them all. Parallelism is supported via the 'parallel' package, 'libdispatch' and 'OpenMP'.

Author(s)

Maintainer: Jon Clayden code@clayden.org (ORCID)

Authors:

See Also

Useful links:


imply documentation built on Sept. 15, 2026, 5:09 p.m.